@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-LcdProc
 #
-# This software is Copyright (c) 2013-2016 by Dominique Dumont.
+# This software is Copyright (c) 2013-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,39 +9,12 @@
 #
 [
   {
-    'class_description' => 'LCDd.conf -- configuration file for the LCDproc server daemon LCDd
+    'class_description' => '
 
-This file contains the configuration for the LCDd server.
-
-The format is ini-file-like. It is divided into sections that start at
-markers that look like [section]. Comments are all line-based comments,
-and are lines that start with \'#\' or \';\'.
-
-The server has a \'central\' section named [server]. For the menu there is
-a section called [menu]. Further each driver has a section which
-defines how the driver acts.
-
-The drivers are activated by specifying them in a driver= line in the
-server section, like:
-
-  Driver=curses
-
-This tells LCDd to use the curses driver.
-The first driver that is loaded and is capable of output defines the
-size of the display. The default driver to use is curses.
-If the driver is specified using the -d <driver> command line option,
-the Driver= options in the config file are ignored.
-
-The drivers read their own options from the respective sections.
-
-Model information extracted from template /etc/LCDd.conf
-
-'.'=head1 BUGS
-
-This model does not support to load several drivers. Loading several drivers is probably a marginal case. Please complain to the author if this assumption is false',
+Model information was extracted from /etc/LCDd.conf',
     'copyright' => [
-      '2011-2013, Dominique Dumont',
-      '1999-2013, William Ferrell and others'
+      '2011-2017, Dominique Dumont',
+      '1999-2017, William Ferrell and others'
     ],
     'element' => [
       'server',
@@ -202,6 +175,23 @@ This model does not support to load several drivers. Loading several drivers is
           ]
         }
       },
+      'Olimex_MOD_LCD1x9',
+      {
+        'config_class_name' => 'LCDd::Olimex_MOD_LCD1x9',
+        'level' => 'hidden',
+        'type' => 'warped_node',
+        'warp' => {
+          'follow' => {
+            'selected' => '- server Driver'
+          },
+          'rules' => [
+            '$selected.is_set(\'Olimex_MOD_LCD1x9\')',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
+      },
       'SureElec',
       {
         'config_class_name' => 'LCDd::SureElec',
@@ -270,6 +260,23 @@ This model does not support to load several drivers. Loading several drivers is
           ]
         }
       },
+      'futaba',
+      {
+        'config_class_name' => 'LCDd::futaba',
+        'level' => 'hidden',
+        'type' => 'warped_node',
+        'warp' => {
+          'follow' => {
+            'selected' => '- server Driver'
+          },
+          'rules' => [
+            '$selected.is_set(\'futaba\')',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
+      },
       'g15',
       {
         'config_class_name' => 'LCDd::g15',
@@ -491,6 +498,23 @@ This model does not support to load several drivers. Loading several drivers is
           ]
         }
       },
+      'linux_input',
+      {
+        'config_class_name' => 'LCDd::linux_input',
+        'level' => 'hidden',
+        'type' => 'warped_node',
+        'warp' => {
+          'follow' => {
+            'selected' => '- server Driver'
+          },
+          'rules' => [
+            '$selected.is_set(\'linux_input\')',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
+      },
       'lirc',
       {
         'config_class_name' => 'LCDd::lirc',
@@ -903,17 +927,32 @@ This model does not support to load several drivers. Loading several drivers is
             }
           ]
         }
+      },
+      'yard2LCD',
+      {
+        'config_class_name' => 'LCDd::yard2LCD',
+        'level' => 'hidden',
+        'type' => 'warped_node',
+        'warp' => {
+          'follow' => {
+            'selected' => '- server Driver'
+          },
+          'rules' => [
+            '$selected.is_set(\'yard2LCD\')',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
       }
     ],
     'license' => 'GPL-2',
     'name' => 'LCDd',
-    'read_config' => [
-      {
-        'backend' => 'IniFile',
-        'config_dir' => '/etc',
-        'file' => 'LCDd.conf'
-      }
-    ]
+    'rw_config' => {
+      'backend' => 'IniFile',
+      'config_dir' => '/etc',
+      'file' => 'LCDd.conf'
+    }
   }
 ]
 ;
